<?php

namespace College\Circular\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use College\Circular\Interfaces\CircularRepositoryInterface;
use College\Circular\Repositories\Presenter\CircularItemTransformer;

/**
 * Pubic API controller class.
 */
class CircularPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \College\Circular\Interfaces\CircularRepositoryInterface $circular
     *
     * @return type
     */
    public function __construct(CircularRepositoryInterface $circular)
    {
        $this->repository = $circular;
        parent::__construct();
    }

    /**
     * Show circular's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $circulars = $this->repository
            ->setPresenter('\\College\\Circular\\Repositories\\Presenter\\CircularListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $circulars['code'] = 2000;
        return response()->json($circulars)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show circular.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $circular = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($circular)) {
            $circular         = $this->itemPresenter($module, new CircularItemTransformer);
            $circular['code'] = 2001;
            return response()->json($circular)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
