<?php

namespace College\Circular\Http\Controllers;
use Litepie\Circular\Http\Requests\CircularRequest;
use Litepie\Circular\Models\Circular;

trait CircularWorkflow {
	
    /**
     * Workflow controller function for circular.
     *
     * @param Model   $circular
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(CircularRequest $request, Circular $circular, $step)
    {

        try {

            $circular->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('circular::circular.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/circular/circular/' . $circular->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/circular/circular/' . $circular->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for circular.
     *
     * @param Model   $circular
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Circular $circular, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $circular->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('circular::circular.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('circular::admin.circular.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('circular::admin.circular.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('circular::admin.circular.message', $data)->render();

        }

    }
}