<?php

namespace College\Circular\Policies;

use App\User;
use College\Circular\Models\Circular;

class CircularPolicy
{

    /**
     * Determine if the given user can view the circular.
     *
     * @param User $user
     * @param Circular $circular
     *
     * @return bool
     */
    public function view(User $user, Circular $circular)
    {
        if ($user->canDo('circular.circular.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $circular->user_id;
    }

    /**
     * Determine if the given user can create a circular.
     *
     * @param User $user
     * @param Circular $circular
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('circular.circular.create');
    }

    /**
     * Determine if the given user can update the given circular.
     *
     * @param User $user
     * @param Circular $circular
     *
     * @return bool
     */
    public function update(User $user, Circular $circular)
    {
        if ($user->canDo('circular.circular.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $circular->user_id;
    }

    /**
     * Determine if the given user can delete the given circular.
     *
     * @param User $user
     * @param Circular $circular
     *
     * @return bool
     */
    public function destroy(User $user, Circular $circular)
    {
        if ($user->canDo('circular.circular.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $circular->user_id;
    }

    /**
     * Determine if the given user can verify the given circular.
     *
     * @param User $user
     * @param Circular $circular
     *
     * @return bool
     */
    public function verify(User $user, Circular $circular)
    {
        if ($user->canDo('circular.circular.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('circular.circular.verify') 
        && $user->is('manager')
        && $circular->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given circular.
     *
     * @param User $user
     * @param Circular $circular
     *
     * @return bool
     */
    public function approve(User $user, Circular $circular)
    {
        if ($user->canDo('circular.circular.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
