<?php

namespace College\Circular\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use College\Circular\Models\Circular;

class CircularAction
{
    /**
     * Perform the complete action.
     *
     * @param Circular $circular
     *
     * @return Circular
     */
    public function complete(Circular $circular)
    {
        try {
            $circular->status = 'complete';
            return $circular->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Circular $circular
     *
     * @return Circular
     */public function verify(Circular $circular)
    {
        try {
            $circular->status = 'verify';
            return $circular->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Circular $circular
     *
     * @return Circular
     */public function approve(Circular $circular)
    {
        try {
            $circular->status = 'approve';
            return $circular->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Circular $circular
     *
     * @return Circular
     */public function publish(Circular $circular)
    {
        try {
            $circular->status = 'publish';
            return $circular->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Circular $circular
     *
     * @return Circular
     */
    public function archive(Circular $circular)
    {
        try {
            $circular->status = 'archive';
            return $circular->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Circular $circular
     *
     * @return Circular
     */
    public function unpublish(Circular $circular)
    {
        try {
            $circular->status = 'unpublish';
            return $circular->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
