<?php

namespace College\Circular\Workflow;

use College\Circular\Models\Circular;
use Validator;

class CircularValidator
{

    /**
     * Determine if the given circular is valid for complete status.
     *
     * @param Circular $circular
     *
     * @return bool / Validator
     */
    public function complete(Circular $circular)
    {
        return Validator::make($circular->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given circular is valid for verify status.
     *
     * @param Circular $circular
     *
     * @return bool / Validator
     */
    public function verify(Circular $circular)
    {
        return Validator::make($circular->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given circular is valid for approve status.
     *
     * @param Circular $circular
     *
     * @return bool / Validator
     */
    public function approve(Circular $circular)
    {
        return Validator::make($circular->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given circular is valid for publish status.
     *
     * @param Circular $circular
     *
     * @return bool / Validator
     */
    public function publish(Circular $circular)
    {
        return Validator::make($circular->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given circular is valid for archive status.
     *
     * @param Circular $circular
     *
     * @return bool / Validator
     */
    public function archive(Circular $circular)
    {
        return Validator::make($circular->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given circular is valid for unpublish status.
     *
     * @param Circular $circular
     *
     * @return bool / Validator
     */
    public function unpublish(Circular $circular)
    {
        return Validator::make($circular->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
